class V1::SearchController < ApplicationController
  before_action :set_search

  # GET v1/search
  # GET v1/search.json
  def index
    search = SearchService.instance(@search, current_user).search
    headers['X-Total-Count'] = search.total_count
    render json: search.results, status: :ok
  rescue SearchService::InvalidSearchError
    render json: @search.errors, status: :bad_request
  end

  # GET v1/search/autocomplete
  # GET v1/search/autocomplete.json
  def autocomplete
    render json: SearchService.autocomplete(@search, current_user), status: :ok
  rescue SearchService::InvalidSearchError
    render json: @search.errors, status: :bad_request
  end

  private

  def set_search
    @search = Search.new(search_params)
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def search_params
    params.permit(:page, :results_per_page, :order, :query, :search_class, tags: [], subjects: [], educational_stages: [], object_types: [])
  end
end
