class Search
  include ActiveModel::Model
  attr_accessor :page, :results_per_page, :order, :query, :search_class, :tags, :subjects, :educational_stages, :object_types

  validates_presence_of :query, :results_per_page, :order, :search_class
  validates_numericality_of :results_per_page, greater_than: 0
  validates :search_class, inclusion: { in: ::SearchService::SEARCH_CLASSES }

  def initialize(params = {})
    super(params.merge(defaults(params)))
  end

  def learning_object?
    search_class == 'LearningObject'
  end

  def collection?
    search_class == 'Collection'
  end

  def user?
    search_class == 'User'
  end

  private

  def defaults(params)
    {
      query: '*',
      order: 'score',
      page: 1,
      results_per_page: 10
    }.select { |key, _value| !params.key?(key) }
  end
end
