class CollectionSerializer < ActiveModel::Serializer
  cache key: 'collection', expires_in: 4.hours, except: [:likes_count, :liked, :reviewed, :complained, :followed]

  def liked
    object.liked? current_user
  end

  def reviewed
    object.reviewed? current_user
  end

  def complained
    object.complained? current_user
  end

  def followed
    object.followed? current_user
  end

  def items_thumbnails
    thumbs = []
    i = 0
    while thumbs.size < 6 && i < object.collection_items.size do
      t = object.collection_items[i].thumbnail
      thumbs << t unless t.blank?
      i=i+1
    end
    thumbs
  end

  attributes :id, :name, :created_at, :updated_at, :description, :privacy, :score, :likes_count, :liked, :followed, :reviewed, :complained, :review_average, :thumbnail, :items_thumbnails

  belongs_to :owner
  has_many :tags
  has_many :subjects
  has_many :educational_stages
  has_many :collection_items
end
