require 'dspace'

class LearningObjectPublisher
  def initialize(dspace_client)
    @dspace = dspace_client
  end

  # create a learning object with draft status
  def create_draft(draft, publisher)
    item = create_dspace_item(draft)
    # save on postgres
    draft.id_dspace = item.id
    draft.publisher = publisher
    draft.save

    update_dspace(draft)

    draft
  end

  # post *media_path* to *learning_object* on dspace
  def upload(learning_object, media_path)
    DspaceUploadWorker.perform_async learning_object.id, media_path, learning_object.description
  end

  ## publish *learning_object*
  # this method will create thumbnails, change state to published and will save it.
  def publish(learning_object)
    return true if learning_object.published?

    learning_object.state = LearningObject.states[:published]
    learning_object.published_at = Time.now
    ThumbnailGenerateWorker.perform_async learning_object.id, learning_object.link if learning_object.link?
    learning_object.save
  end

  def update_dspace(object)
    metadata = []
    dspace_metadata_mapper(object).each do |key, value|
      next if value.blank?
      value = [value] unless value.is_a? Array
      value.each do |v|
        metadata << { 'key' => key, 'value' => v, 'language' => object.language.try(:code) || 'pt' } unless v.blank?
      end
    end
    @dspace.items.add_metadata(metadata, id: object.id_dspace) unless metadata.empty?
  end

  private

  def create_dspace_item(draft)
    @dspace.collections.create_item(build_dspace_item(draft), id: DspaceService::TEST_COLLECTION)
  end

  def build_dspace_item(draft)
    ::Dspace::Item.new('name' => draft.name)
  end

  def dspace_metadata_mapper(object)
    {
      'dc.title' => object.name,
      'dc.object.url' => object.link,
      'dc.contributor.author' => object.author,
      'dc.description' => object.description,
      'dc.language' => object.language.try(:code),
      'dc.type' => object.object_type.try(:name),
      'dc.rights.license' => object.license.try(:name),
      # 'dc.subject.category' => object.subjects,
      'dc.date.submitted' => object.created_at.to_s
    }
  end
end
