module PackageService
  class Generator

    attr_reader :objects

    def initialize(objects)
      @objects = objects.is_a?(Array) ? objects : [objects]
      @filename = nil

      raise 'Invalid objects for PackageService' unless valid?
    end

    def generate
      PackageWorker.perform_async(objects_map, filename)
    end

    def filename
      while @filename.nil? do
        name = "#{SecureRandom.hex(12)}.zip"
        @filename = name unless File.exist?(PackageService.file_root(name))
      end
      @filename
    end

    private

    def valid?
      allowed_classes = PackageService.allowed_classes

      @objects.each do |object|
        return false unless allowed_classes.include? object.class.name
      end

      true
    end

    def objects_map
      @objects.map { |o| { class: o.class, id: o.id } }
    end
  end
end
