namespace :db do
  desc 'Dumps the database to backups'
  task :dump, [:filename] => :environment do |_task, args|
    cmd = nil
    with_config do |_app, host, db, user, password|
      cmd = "PGPASSWORD=\"#{password}\" pg_dump -F c -d #{db} -U #{user} -f #{Rails.root}/db/backups/#{Time.now.strftime('%Y%m%d%H%M%S')}_#{db}_#{args.filename}.psql"
    end
    puts cmd
    system cmd
  end

  desc 'Restores the database from backups'
  task :restore, [:date, :name] => :environment do |_task, args|
    if args.date.present? || args.name.present?
      cmd = nil
      with_config do |_app, _host, db, user, password, pool, timeout|
        # filename = args.name.nil? ? "#{args.date}_#{db}" : args.name.to_s
        # puts "pool: #{pool} / timeout: #{timeout}"
        # reset = "PGPASSWORD=\"#{password}\" psql -c \"SELECT pg_terminate_backend(procpid) FROM pg_stat_activity WHERE procpid <> pg_backend_pid();\" -U #{user} -d '#{db}'"
        # system reset
        cmd = "PGPASSWORD=\"#{password}\" pg_restore -F c -U #{user} -d #{db} -c -C #{Rails.root}/db/backups/#{args.name}.psql"
      end
      Rake::Task['db:drop:all'].reenable
      Rake::Task['db:drop:all'].invoke
      sleep(3)
      Rake::Task['db:create'].reenable
      Rake::Task['db:create'].invoke
      sleep(3)

      puts cmd
      system cmd
    else
      puts 'Please pass a date to the task'
    end
  end

  private

  def with_config
    yield Rails.application.class.parent_name.underscore,
    ActiveRecord::Base.connection_config[:host],
    ActiveRecord::Base.connection_config[:database],
    ActiveRecord::Base.connection_config[:username],
    ActiveRecord::Base.connection_config[:password],
    ActiveRecord::Base.connection_config[:pool],
    ActiveRecord::Base.connection_config[:timeout]
  end
end
