require 'acceptance_helpers'
require 'shared/contexts'

resource 'Activities' do

  before { 12.times { create(:learning_object); create(:user) } }

  let(:learning_objects) { LearningObject.all }
  let(:users) { User.all }

  get '/v1/activities' do
    include_context "authenticate_user"

    before do
      create(:like, user: @user)
    end

    example 'Showing all users public activities' do
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/activities/me' do
    include_context "authenticate_user"

    before do
      create(:like, user: @user)
    end

    example 'Showing logged user activities' do
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/users/:id/activities' do
    include_context "authenticate_user"

    let(:id) { users.first.id }

    before do
      create(:follow, followable: users.first, user: @user)
    end

    example 'Showing activities from a specific user' do
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/feed' do
    include_context "authenticate_user"

    before do
      create(:like, user: @user)
    end

    example 'Showing all activities that logged user can see' do
      do_request
      expect(status).to eq(200)
    end
  end


end
