require 'acceptance_helpers'
require 'shared/contexts'

resource 'Bookmarks' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:learning_object) } }

  let(:bookmarks) { Bookmark.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/users/:user_id/bookmarks' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'

    let(:user_id) { @user.id }

    before do
      create(:bookmark, user: @user)
    end

    example_request 'Getting bookmarks' do
      expect(status).to eq(200)
    end
  end

  post 'v1/users/:user_id/bookmarks' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'
    parameter :id, 'The id of the object', scope: :bookmarks
    parameter :type, 'Represents the type of bookmark, [ LearningObject, Collection]', scope: :bookmarks

    let(:user_id) { @user.id }
    let(:id) { learning_objects.first.id }
    let(:type) { 'LearningObject' }
    let(:raw_post) { params.to_json }

    example_request 'Adding a bookmark' do
      expect(status).to eq(201)
    end
  end

  delete 'v1/users/:user_id/bookmarks/:bookmark_id' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'
    parameter :bookmark_id, 'The id of the bookmark'
    parameter :id, 'The id of the object', scope: :bookmarks
    parameter :type, 'Represents the type of bookmark, [ LearningObject, Collection]', scope: :bookmarks

    let(:user_id) { @user.id }
    let(:bookmark_id) { @bookmark.id }
    let(:id) { learning_objects.first.id }
    let(:type) { 'LearningObject' }
    let(:raw_post) { params.to_json }

    before do
      @bookmark = create(:bookmark, user: @user, bookmarkable: learning_objects.first )
    end

    example_request 'Removing a bookmark' do
      expect(status).to eq(200)
    end
  end

end
