require 'acceptance_helpers'

resource 'Complaints' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before {
    12.times {
      create(:complaint)
      create(:complaint_reason)
      create(:learning_object)
    }
  }

  let(:complaints) { Complaint.all }
  let(:complaint_reasons) { ComplaintReason.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/complaints' do
    parameter :limit, 'Limit of complaints'
    parameter :offset, 'Offset of complaints'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of complaints' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Complaint.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end


  post '/v1/complaints' do
    include_context 'authenticate_user'

    parameter :user_id, 'The id of user', scope: :complaint
    parameter :description, 'The description of the complaint', scope: :complaint
    parameter :complainable_id, 'The id of the complainable [LearningObject, Review, User, Collection]', scope: :complaint
    parameter :complainable_type, 'Represents a type of the complainable [LearningObject, Review, User, Collection]', scope: :complaint
    parameter :complaint_reason_id, 'Id of the reason of the complaint', scope: :complaint


    let(:user_id) { @user.id }
    let(:description) { Faker::Lorem::sentence }
    let(:complainable_id) { learning_objects.first.id }
    let(:complainable_type) { "LearningObject" }
    let(:complaint_reason_id) { complaint_reasons.first.id }
    let(:raw_post) { params.to_json }
  
    example_request 'Creating a complaint' do
      expect(status).to eq(201)
    end

  end


end
