require 'acceptance_helpers'

resource 'Contacts' do

  before { 12.times { create(:contact) } }

  let(:contacts) { Contact.all }

  get '/v1/contacts' do

    example_request 'Getting all contacts' do
      expect(status).to eq(200)
    end
  end

  get '/v1/contacts/:id' do

    let(:id) { contacts.first.id }

    example_request 'Getting a contact' do
      expect(status).to eq(200)
    end
  end


  post '/v1/contacts' do

    parameter :name, 'The name of the contact', scope: :contact
    parameter :link, 'The email of the contact', scope: :contact
    parameter :description, 'The message of the contact', scope: :contact

    let(:id) { contacts.first.id }
    let(:name) { Faker::Name.name }
    let(:email) { Faker::Internet.email }
    let(:message) { Faker::Lorem.sentence }
    let(:raw_post) { params.to_json }

    example_request 'Create contacts' do
      expect(status).to eq(201)
    end
  end

  put '/v1/contacts/:id' do

    parameter :name, 'The name of the contact', scope: :contact
    parameter :link, 'The email of the contact', scope: :contact
    parameter :description, 'The message of the contact', scope: :contact

    let(:id) { contacts.first.id }
    let(:name) { Faker::Name.name }
    let(:email) { Faker::Internet.email }
    let(:message) { Faker::Lorem.sentence }
    let(:raw_post) { params.to_json }

    example_request 'Updating contacts' do
      expect(status).to eq(200)
    end
  end

  delete '/v1/contacts/:id' do

    let(:id) { contacts.first.id }

    example_request 'Destroy a contact' do
      expect(status).to eq(200)
    end
  end

end
