require 'acceptance_helpers'

resource 'Educational Stages' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:educational_stage); create(:learning_object) } }

  let(:educationalstages) { EducationalStage.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/educational_stages' do
    parameter :limit, 'Limit of educational stages'
    parameter :offset, 'Offset of educational stages'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of educational stages' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(EducationalStage.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  post '/v1/:type/:id/educational_stages' do
    include_context "authenticate_user"

    parameter :id, 'The id of object'
    parameter :type, 'Represents the type of object, [learning_objects, collection]'

    parameter :educational_stages, 'array with the educational_stages ids'

    let(:type) { 'learning_objects' }
    let(:id) { @learning_object.id }
    let(:educational_stages) { [educationalstages.first.id] }
    let(:raw_post) { params.to_json }

    before do
      @learning_object = create(:learning_object, publisher: @user)
    end

    example_request 'Adding Educational Stages' do
      expect(status).to eq(201)
    end
  end

  delete '/v1/:type/:id/educational_stages' do
    include_context "authenticate_user"

    parameter :id, 'The id of object'
    parameter :type, 'Represents the type of object, [learning_objects, collection]'
    parameter :educational_stages, 'array with the educational_stages ids'

    let(:type) { 'learning_objects' }
    let(:id) {@learning_object.id}
    let(:educational_stages) { [educationalstages.first.id] }
    let(:raw_post) { params.to_json }

    before do
      @learning_object = create(:learning_object, publisher: @user)
      create(:stage_relation, stageable: @learning_object, educational_stage: educationalstages.first)
    end

    example_request 'Removing Educational Stages' do
      #do_request
      expect(status).to eq(200)
    end
  end
end
