require 'acceptance_helpers'

resource 'Mime Types' do

  before { 12.times { create(:mime_type) } }

  let(:mime_types) { MimeType.all }

  get '/v1/mime_types' do

    example_request 'Getting all mime_types' do
      expect(status).to eq(200)
    end
  end

  get '/v1/mime_types/:id' do

    let(:id) { mime_types.first.id }

    example_request 'Getting a mime_type' do
      expect(status).to eq(200)
    end
  end


  post '/v1/mime_types' do
    include_context "authenticate_user"

    parameter :extension, 'The name of the mime_type', scope: :mime_type
    parameter :mime_type, 'The mime_type', scope: :mime_type

    let(:id) { mime_types.first.id }
    let(:extension) { Faker::File.extension }
    let(:mime_type) { Faker::File.mime_type }
    let(:raw_post) { params.to_json }

    example_request 'Create mime_types' do
      expect(status).to eq(201)
    end
  end

  put '/v1/mime_types/:id' do
    include_context "authenticate_user"

    parameter :extension, 'The name of the mime_type', scope: :mime_type
    parameter :mime_type, 'The mime_type', scope: :mime_type

    let(:id) { mime_types.first.id }
    let(:extension) { Faker::File.extension }
    let(:mime_type) {  Faker::File.mime_type }
    let(:raw_post) { params.to_json }

    example_request 'Updating mime_types' do
      expect(status).to eq(200)
    end
  end

  delete '/v1/mime_types/:id' do
    include_context "authenticate_user"

    let(:id) { mime_types.first.id }

    example_request 'Destroy a mime_type' do
      expect(status).to eq(200)
    end
  end

end
