require 'acceptance_helpers'
require 'shared/contexts'

resource 'Reviews' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:learning_object) } }

  let(:learning_objects) { LearningObject.all }
  let(:reviews) { Review.all }

  get '/v1/:type/:id/reviews' do
    parameter :type, 'type of object [\'learning_objects\', \'collections\']'

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }

    example_request 'Get a list of reviews' do
      expect(path).to eq("/v1/learning_objects/#{id}/reviews") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Review.where(reviewable: learning_objects.first)))
      expect(status).to eq(200)
    end
  end

  post '/v1/:type/:id/reviews' do
    include_context 'authenticate_user'

    parameter :id, 'The id of object'
    parameter :type, 'type of object [\'learning_objects\', \'collections\']'
    parameter :name, 'The title of review', scope: :review
    parameter :description, 'A short description', scope: :review
    parameter :pros, 'Pros description', scope: :review
    parameter :cons, 'Cons description', scope: :review
    parameter :review_ratings_attributes, 'Ratings of attributes belonging to the review', scope: :review

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }
    let(:name) { Faker::Lorem::word }
    let(:description) { Faker::Lorem::sentence }
    let(:pros) { Faker::Lorem::sentence}
    let(:cons) { Faker::Lorem::sentence}
    let(:review_ratings_attributes) { [ { rating_id: 1, value: 3} ] }
    let(:raw_post) { params.to_json }

    example_request 'Creating a Review' do
      expect(status).to eq(201)
    end
  end


  put '/v1/:type/:id/reviews/:review_id' do
    include_context 'authenticate_user'

    parameter :id, 'The id of object'
    parameter :review_id, 'The id of review'
    parameter :type, 'type of object [\'learning_objects\', \'collections\']'
    parameter :name, 'The title of review', scope: :review
    parameter :description, 'A short description', scope: :review
    parameter :pros, 'Pros description', scope: :review
    parameter :cons, 'Cons description', scope: :review
    parameter :review_ratings_attributes, 'Ratings of attributes belonging to the review', scope: :review

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }
    let(:review_id) { @review.id }
    let(:name) { Faker::Lorem::word }
    let(:description) { Faker::Lorem::sentence }
    let(:pros) { Faker::Lorem::sentence}
    let(:cons) { Faker::Lorem::sentence}
    let(:review_ratings_attributes) { [ { rating_id: 1, value: 3} ] }
    let(:raw_post) { params.to_json }

    before do
      @review = create(:review, user: @user, reviewable: learning_objects.first)
    end

    example_request 'Updating a Review' do
      #TODO: compair responses
      expect(status).to eq(200)
    end
  end

  post '/v1/:type/:id/reviews/:review_id/rate' do
    include_context 'authenticate_user'

    parameter :id, 'The id of object'
    parameter :type, 'type of object [\'learning_objects\', \'collections\']'
    parameter :review_id, 'The id of review'
    parameter :approves, 'If user likes the review or not.'

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }
    let(:review_id) { reviews.first.id }
    let(:approves) { 'true' }
    let(:raw_post) { params.to_json }

    example_request 'Rating Review' do
      expect(path).to eq("/v1/learning_objects/#{id}/reviews/#{review_id}/rate") # `:id` is replaced with the value of `id`
      expect(JSON.parse(response_body)['approves']).to eq(true)
      expect(status).to eq(201)
    end
  end


  delete '/v1/:type/:id/reviews/:review_id' do
    include_context 'authenticate_user'

    parameter :id, 'The id of object'
    parameter :type, 'type of object [\'learning_objects\', \'collections\']'
    parameter :review_id, 'The id of review'

    before do
      @review = create(:review, user: @user, reviewable: learning_objects.first)
    end

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }
    let(:review_id) { @review.id }

    example_request 'Delete a review' do
      expect(path).to eq("/v1/learning_objects/#{id}/reviews/#{review_id}") # `:id` is replaced with the value of `id`
      expect(status).to eq(200)
    end
  end

end
