require 'acceptance_helpers'

resource 'Suggestions' do

  before { 12.times { create(:suggestion) } }

  let(:suggestions) { Suggestion.all }

  get '/v1/suggestions' do

    example_request 'Getting all suggestions' do
      expect(status).to eq(200)
    end
  end

  get '/v1/suggestions/:id' do

    let(:id) { suggestions.first.id }

    example_request 'Getting a suggestion' do
      do_request
      expect(status).to eq(200)
    end
  end


  post '/v1/suggestions' do

    parameter :name, 'The suggestion', scope: :suggestion
    parameter :link, 'The link to site with the suggested contents', scope: :suggestion
    parameter :description, 'The description of the suggested contents', scope: :suggestion


    let(:id) { suggestions.first.id }
    let(:name) { Faker::Lorem.word }
    let(:link) { Faker::Lorem.word }
    let(:description) { Faker::Lorem.sentence }
    let(:raw_post) { params.to_json }

    example_request 'Create suggestions' do
      expect(status).to eq(201)
    end
  end

  put '/v1/suggestions/:id' do

    parameter :name, 'The suggestion', scope: :suggestion
    parameter :link, 'The link to site with the suggested contents', scope: :suggestion
    parameter :description, 'The description of the suggested contents', scope: :suggestion


    let(:id) { suggestions.first.id }
    let(:name) { Faker::Lorem.word }
    let(:raw_post) { params.to_json }

    example_request 'Updating suggestions' do
      expect(status).to eq(200)
    end
  end

  delete '/v1/suggestions/:id' do

    let(:id) { suggestions.first.id }

    example_request 'Destroy suggestions' do
      expect(status).to eq(200)
    end
  end

end
